---
description: An in-depth look into Vector's delivery guarantees
---

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     scripts/generate/templates/docs/about/guarantees.md.erb
-->

# Guarantees

Vector was designed with a focus on providing clear guarantees. Below you'll
find a support matrix so you know exactly what type of guarantee you can expect
for your combination of sources and sinks. This helps you make the appropriate
tradeoffs or your usecase.

## Support Matrix

The following matrix outlines the guarantee support for each [sink][docs.sinks]
and [source][docs.sources].

| Name | Description |
|:-----|:------------|
| **Sources** | |
| [`file` source][docs.sources.file] | `best_effort` |
| [`journald` source][docs.sources.journald] | `best_effort` |
| [`kafka` source][docs.sources.kafka] | `at_least_once` |
| [`statsd` source][docs.sources.statsd] | `best_effort` |
| [`stdin` source][docs.sources.stdin] | `at_least_once` |
| [`syslog` source][docs.sources.syslog] | `best_effort` |
| [`tcp` source][docs.sources.tcp] | `best_effort` |
| [`udp` source][docs.sources.udp] | `best_effort` |
| [`vector` source][docs.sources.vector] | `best_effort` |
| **Sinks** | |
| [`aws_cloudwatch_logs` sink][docs.sinks.aws_cloudwatch_logs] | `at_least_once` |
| [`aws_kinesis_streams` sink][docs.sinks.aws_kinesis_streams] | `at_least_once` |
| [`aws_s3` sink][docs.sinks.aws_s3] | `at_least_once` |
| [`blackhole` sink][docs.sinks.blackhole] | `best_effort` |
| [`clickhouse` sink][docs.sinks.clickhouse] | `best_effort` |
| [`console` sink][docs.sinks.console] | `best_effort` |
| [`elasticsearch` sink][docs.sinks.elasticsearch] | `best_effort` |
| [`file` sink][docs.sinks.file] | `best_effort` |
| [`http` sink][docs.sinks.http] | `at_least_once` |
| [`kafka` sink][docs.sinks.kafka] | `at_least_once` |
| [`prometheus` sink][docs.sinks.prometheus] | `best_effort` |
| [`splunk_hec` sink][docs.sinks.splunk_hec] | `at_least_once` |
| [`tcp` sink][docs.sinks.tcp] | `best_effort` |
| [`vector` sink][docs.sinks.vector] | `best_effort` |

## At Least Once Delivery

"At least once" delivery guarantees that an [event][docs.event] received by
Vector will be delivered at least once to the configured destination(s). While
rare, it is possible for an event to be delivered more than once (see the
[Does Vector support exactly once delivery](#does-vector-support-exactly-once-delivery)
FAQ below).

To achieve at least once delivery your source must be configured to use `disk`
based buffers:

{% code-tabs %}
{% code-tabs-item title="vector.toml" %}
```coffeescript
[sinks.my_sink_id]
  # ...

  [sinks.my_sink_id.buffer]
    type = "disk"
    when_full = "block"
    max_size = 104900000 # 100MiB
```
{% endcode-tabs-item %}
{% endcode-tabs %}

Each [sink][docs.sinks] documents the buffer options.


## Best Effort Delivery

"Best effort" delivery has no guarantees and means that Vector will make a best
effort to deliver each event. This means it is possible for the occasional
event to not be lost.

## FAQs

### Do I need at least once delivery?

One of the unique advantages of the logging use case is that data is usually
used for diagnostic purposes only. Therefore, losing the occasional event
has little impact on your business. This affords you the opportunity to
provision your pipeline towards performance, simplicity, and cost reduction.
On the other hand, if you're using your data to perform business critical
functions, then data loss is not acceptable and therefore requires "at least
once" delivery.

To clarify, even though a source or sink is marked as "best effort" it does
not mean Vector takes delivery lightly. In fact, once data is within the
boundary of Vector it will not be lost if you've configured on-disk buffers.
Data loss for "best effort" sources and sinks are almost always due to the
limitations of the underlying protocol.

### Does Vector support exactly once delivery?

No, Vector does not support exactly once delivery. There are future plans to
partially support this for sources and sinks that support it (Kafka, for
example), but it remains unclear if Vector will ever be able to achieve this.
We recommend [subscribing to our mailing list](https://vector.dev), which will
keep you in the loop if this ever changes.


[docs.event]: ../setup/getting-started/sending-your-first-event.md
[docs.sinks.aws_cloudwatch_logs]: ../usage/configuration/sinks/aws_cloudwatch_logs.md
[docs.sinks.aws_kinesis_streams]: ../usage/configuration/sinks/aws_kinesis_streams.md
[docs.sinks.aws_s3]: ../usage/configuration/sinks/aws_s3.md
[docs.sinks.blackhole]: ../usage/configuration/sinks/blackhole.md
[docs.sinks.clickhouse]: ../usage/configuration/sinks/clickhouse.md
[docs.sinks.console]: ../usage/configuration/sinks/console.md
[docs.sinks.elasticsearch]: ../usage/configuration/sinks/elasticsearch.md
[docs.sinks.file]: ../usage/configuration/sinks/file.md
[docs.sinks.http]: ../usage/configuration/sinks/http.md
[docs.sinks.kafka]: ../usage/configuration/sinks/kafka.md
[docs.sinks.prometheus]: ../usage/configuration/sinks/prometheus.md
[docs.sinks.splunk_hec]: ../usage/configuration/sinks/splunk_hec.md
[docs.sinks.tcp]: ../usage/configuration/sinks/tcp.md
[docs.sinks.vector]: ../usage/configuration/sinks/vector.md
[docs.sinks]: ../usage/configuration/sinks
[docs.sources.file]: ../usage/configuration/sources/file.md
[docs.sources.journald]: ../usage/configuration/sources/journald.md
[docs.sources.kafka]: ../usage/configuration/sources/kafka.md
[docs.sources.statsd]: ../usage/configuration/sources/statsd.md
[docs.sources.stdin]: ../usage/configuration/sources/stdin.md
[docs.sources.syslog]: ../usage/configuration/sources/syslog.md
[docs.sources.tcp]: ../usage/configuration/sources/tcp.md
[docs.sources.udp]: ../usage/configuration/sources/udp.md
[docs.sources.vector]: ../usage/configuration/sources/vector.md
[docs.sources]: ../usage/configuration/sources
