---
description: Ingests data through log records from journald and outputs `log` events.
---

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     scripts/generate/templates/docs/usage/configuration/sources/journald.md.erb
-->

# journald source

![][assets.journald_source]

{% hint style="warning" %}
The `journald` source is in beta. Please see the current
[enhancements][urls.journald_source_enhancements] and
[bugs][urls.journald_source_bugs] for known issues.
We kindly ask that you [add any missing issues][urls.new_journald_source_issue]
as it will help shape the roadmap of this component.
{% endhint %}

The `journald` source ingests data through log records from journald and outputs [`log`][docs.data-model.log] events.

## Config File

{% code-tabs %}
{% code-tabs-item title="vector.toml (simple)" %}
```coffeescript
[sources.my_source_id]
  # REQUIRED
  type = "journald" # must be: "journald"
  
  # OPTIONAL
  units = ["ntpd", "sysinit.target"]

  # For a complete list of options see the "advanced" tab above.
```
{% endcode-tabs-item %}
{% code-tabs-item title="vector.toml (advanced)" %}
```coffeescript
[sources.journald_source]
  # The component type
  # 
  # * required
  # * no default
  # * must be: "journald"
  type = "journald"

  # Include only entries from the current runtime (boot)
  # 
  # * optional
  # * default: true
  current_runtime_only = true

  # The directory used to persist the journal checkpoint position. By default,
  # the global `data_dir` is used. Please make sure the Vector project has write
  # permissions to this dir.
  # 
  # * optional
  # * no default
  data_dir = "/var/lib/vector"

  # Include only entries from the local system
  # 
  # * optional
  # * default: true
  local_only = true

  # The list of units names to monitor. If empty or not present, all units are
  # accepted. Unit names lacking a `"."` will have `".service"` appended to make
  # them a valid service unit name.
  # 
  # * optional
  # * no default
  units = ["ntpd", "sysinit.target"]
```
{% endcode-tabs-item %}
{% endcode-tabs %}

## Examples

Given the following journald record:

{% code-tabs %}
{% code-tabs-item title="journald record" %}

```
__REALTIME_TIMESTAMP=1564173027000443
__MONOTONIC_TIMESTAMP=98694000446
_BOOT_ID=124c781146e841ae8d9b4590df8b9231
SYSLOG_FACILITY=3
_UID=0
_GID=0
_CAP_EFFECTIVE=3fffffffff
_MACHINE_ID=c36e9ea52800a19d214cb71b53263a28
_HOSTNAME=lorien.example.com
PRIORITY=6
_TRANSPORT=stdout
_STREAM_ID=92c79f4b45c4457490ebdefece29995e
SYSLOG_IDENTIFIER=ntpd
_PID=2156
_COMM=ntpd
_EXE=/usr/sbin/ntpd
_CMDLINE=ntpd: [priv]
_SYSTEMD_CGROUP=/system.slice/ntpd.service
_SYSTEMD_UNIT=ntpd.service
_SYSTEMD_SLICE=system.slice
_SYSTEMD_INVOCATION_ID=496ad5cd046d48e29f37f559a6d176f8
MESSAGE=reply from 192.168.1.2: offset -0.001791 delay 0.000176, next query 1500s
```
{% endcode-tabs-item %}
{% endcode-tabs %}

A [`log` event][docs.data-model.log] will be emitted with the following structure:

{% code-tabs %}
{% code-tabs-item title="log" %}
```javascript
{
  "timestamp": <2019-07-26T20:30:27.000443Z>,
  "message": "reply from 192.168.1.2: offset -0.001791 delay 0.000176, next query 1500s",
  "host": "lorien.example.com",
  "__REALTIME_TIMESTAMP": "1564173027000443",
  "__MONOTONIC_TIMESTAMP": "98694000446",
  "_BOOT_ID": "124c781146e841ae8d9b4590df8b9231",
  "SYSLOG_FACILITY": "3",
  "_UID": "0",
  "_GID": "0",
  "_CAP_EFFECTIVE": "3fffffffff",
  "_MACHINE_ID": "c36e9ea52800a19d214cb71b53263a28",
  "PRIORITY": "6",
  "_TRANSPORT": "stdout",
  "_STREAM_ID": "92c79f4b45c4457490ebdefece29995e",
  "SYSLOG_IDENTIFIER": "ntpd",
  "_PID": "2156",
  "_COMM": "ntpd",
  "_EXE": "/usr/sbin/ntpd",
  "_CMDLINE": "ntpd: [priv]",
  "_SYSTEMD_CGROUP": "/system.slice/ntpd.service",
  "_SYSTEMD_UNIT": "ntpd.service",
  "_SYSTEMD_SLICE": "system.slice",
  "_SYSTEMD_INVOCATION_ID": "496ad5cd046d48e29f37f559a6d176f8"
}
```

Vector extracts the `"MESSAGE"` field as `"message"`, `"_HOSTNAME"` as
`"host"`, and parses `"_SOURCE_REALTIME_TIMESTAMP"` into `"timestamp"`. All
other fields from journald are kept intact from the source record. You can
further parse the `"message"` key with a [transform][docs.transforms], such as
the [`regex_parser` transform][docs.transforms.regex_parser].
{% endcode-tabs-item %}
{% endcode-tabs %}

## How It Works

### Delivery Guarantee

Due to the nature of this component, it offers a
[**best effort** delivery guarantee][docs.guarantees#best-effort-delivery].

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.

## Troubleshooting

The best place to start with troubleshooting is to check the
[Vector logs][docs.monitoring#logs]. This is typically located at
`/var/log/vector.log`, then proceed to follow the
[Troubleshooting Guide][docs.troubleshooting].

If the [Troubleshooting Guide][docs.troubleshooting] does not resolve your
issue, please:

1. Check for any [open `journald_source` issues][urls.journald_source_issues].
2. If encountered a bug, please [file a bug report][urls.new_journald_source_bug].
3. If encountered a missing feature, please [file a feature request][urls.new_journald_source_enhancement].
4. If you need help, [join our chat/forum community][urls.vector_chat]. You can post a question and search previous questions.

## Resources

* [**Issues**][urls.journald_source_issues] - [enhancements][urls.journald_source_enhancements] - [bugs][urls.journald_source_bugs]
* [**Source code**][urls.journald_source_source]


[assets.journald_source]: ../../../assets/journald-source.svg
[docs.configuration#environment-variables]: ../../../usage/configuration#environment-variables
[docs.data-model.log]: ../../../about/data-model/log.md
[docs.guarantees#best-effort-delivery]: ../../../about/guarantees.md#best-effort-delivery
[docs.monitoring#logs]: ../../../usage/administration/monitoring.md#logs
[docs.transforms.regex_parser]: ../../../usage/configuration/transforms/regex_parser.md
[docs.transforms]: ../../../usage/configuration/transforms
[docs.troubleshooting]: ../../../usage/guides/troubleshooting.md
[urls.journald_source_bugs]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22source%3A+journald%22+label%3A%22Type%3A+bug%22
[urls.journald_source_enhancements]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22source%3A+journald%22+label%3A%22Type%3A+enhancement%22
[urls.journald_source_issues]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22source%3A+journald%22
[urls.journald_source_source]: https://github.com/timberio/vector/tree/master/src/sources/journald.rs
[urls.new_journald_source_bug]: https://github.com/timberio/vector/issues/new?labels=source%3A+journald&labels=Type%3A+bug
[urls.new_journald_source_enhancement]: https://github.com/timberio/vector/issues/new?labels=source%3A+journald&labels=Type%3A+enhancement
[urls.new_journald_source_issue]: https://github.com/timberio/vector/issues/new?labels=source%3A+journald
[urls.vector_chat]: https://chat.vector.dev
