---
description: Ingests data through Kafka 0.9 or later and outputs `log` events.
---

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     scripts/generate/templates/docs/usage/configuration/sources/kafka.md.erb
-->

# kafka source

![][assets.kafka_source]

{% hint style="warning" %}
The `kafka` source is in beta. Please see the current
[enhancements][urls.kafka_source_enhancements] and
[bugs][urls.kafka_source_bugs] for known issues.
We kindly ask that you [add any missing issues][urls.new_kafka_source_issue]
as it will help shape the roadmap of this component.
{% endhint %}

The `kafka` source ingests data through Kafka 0.9 or later and outputs [`log`][docs.data-model.log] events.

## Config File

{% code-tabs %}
{% code-tabs-item title="vector.toml (simple)" %}
```coffeescript
[sources.my_source_id]
  type = "kafka" # must be: "kafka"
  bootstrap_servers = "10.14.22.123:9092,10.14.23.332:9092"
  group_id = "consumer-group-name"
  topics = ["topic-1", "topic-2", "^(prefix1|prefix2)-.+"]

  # For a complete list of options see the "advanced" tab above.
```
{% endcode-tabs-item %}
{% code-tabs-item title="vector.toml (advanced)" %}
```coffeescript
[sources.kafka_source]
  # The component type
  # 
  # * required
  # * no default
  # * must be: "kafka"
  type = "kafka"

  # A comma-separated list of host and port pairs that are the addresses of the
  # Kafka brokers in a "bootstrap" Kafka cluster that a Kafka client connects to
  # initially to bootstrap itself.
  # 
  # * required
  # * no default
  bootstrap_servers = "10.14.22.123:9092,10.14.23.332:9092"

  # The consumer group name to be used to consume events from Kafka.
  # 
  # * required
  # * no default
  group_id = "consumer-group-name"

  # The Kafka topics names to read events from. Regex is supported if the topic
  # begins with `^`.
  # 
  # * required
  # * no default
  topics = ["topic-1", "topic-2", "^(prefix1|prefix2)-.+"]

  # If offsets for consumer group do not exist, set them using this strategy.
  # librdkafka documentation for `auto.offset.reset` option for explanation.
  # 
  # * optional
  # * no default
  auto_offset_reset = "smallest"
  auto_offset_reset = "earliest"
  auto_offset_reset = "beginning"
  auto_offset_reset = "largest"
  auto_offset_reset = "latest"
  auto_offset_reset = "end"
  auto_offset_reset = "error"

  # The log field name to use for the topic key. If unspecified, the key would
  # not be added to the log event. If the message has null key, then this field
  # would not be added to the log event.
  # 
  # * optional
  # * no default
  key_field = "user_id"

  # The Kafka session timeout in milliseconds.
  # 
  # * optional
  # * no default
  # * unit: milliseconds
  session_timeout_ms = 5000
  session_timeout_ms = 10000
```
{% endcode-tabs-item %}
{% endcode-tabs %}

## Examples

Given the following message in a Kafka topic:

{% code-tabs %}
{% code-tabs-item title="stdin" %}
```
2019-02-13T19:48:34+00:00 [info] Started GET "/" for 127.0.0.1
```
{% endcode-tabs-item %}
{% endcode-tabs %}

A [`log` event][docs.data-model.log] will be emitted with the following structure:

{% code-tabs %}
{% code-tabs-item title="log" %}
```javascript
{
  "timestamp": <timestamp> # current time,
  "message": "2019-02-13T19:48:34+00:00 [info] Started GET "/" for 127.0.0.1",
  "host": "10.2.22.122" # current nostname
}
```

The "timestamp" and `"host"` keys were automatically added as context. You can
further parse the `"message"` key with a [transform][docs.transforms], such as
the [`regex_parser` transform][docs.transforms.regex_parser].
{% endcode-tabs-item %}
{% endcode-tabs %}

## How It Works

### Delivery Guarantee

This component offers an [**at least once** delivery guarantee][docs.guarantees#at-least-once-delivery]
if your [pipeline is configured to achieve this][docs.guarantees#at-least-once-delivery].

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.

## Troubleshooting

The best place to start with troubleshooting is to check the
[Vector logs][docs.monitoring#logs]. This is typically located at
`/var/log/vector.log`, then proceed to follow the
[Troubleshooting Guide][docs.troubleshooting].

If the [Troubleshooting Guide][docs.troubleshooting] does not resolve your
issue, please:

1. Check for any [open `kafka_source` issues][urls.kafka_source_issues].
2. If encountered a bug, please [file a bug report][urls.new_kafka_source_bug].
3. If encountered a missing feature, please [file a feature request][urls.new_kafka_source_enhancement].
4. If you need help, [join our chat/forum community][urls.vector_chat]. You can post a question and search previous questions.

## Resources

* [**Issues**][urls.kafka_source_issues] - [enhancements][urls.kafka_source_enhancements] - [bugs][urls.kafka_source_bugs]
* [**Source code**][urls.kafka_source_source]


[assets.kafka_source]: ../../../assets/kafka-source.svg
[docs.configuration#environment-variables]: ../../../usage/configuration#environment-variables
[docs.data-model.log]: ../../../about/data-model/log.md
[docs.guarantees#at-least-once-delivery]: ../../../about/guarantees.md#at-least-once-delivery
[docs.monitoring#logs]: ../../../usage/administration/monitoring.md#logs
[docs.transforms.regex_parser]: ../../../usage/configuration/transforms/regex_parser.md
[docs.transforms]: ../../../usage/configuration/transforms
[docs.troubleshooting]: ../../../usage/guides/troubleshooting.md
[urls.kafka_source_bugs]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22source%3A+kafka%22+label%3A%22Type%3A+bug%22
[urls.kafka_source_enhancements]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22source%3A+kafka%22+label%3A%22Type%3A+enhancement%22
[urls.kafka_source_issues]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22source%3A+kafka%22
[urls.kafka_source_source]: https://github.com/timberio/vector/tree/master/src/sources/kafka.rs
[urls.new_kafka_source_bug]: https://github.com/timberio/vector/issues/new?labels=source%3A+kafka&labels=Type%3A+bug
[urls.new_kafka_source_enhancement]: https://github.com/timberio/vector/issues/new?labels=source%3A+kafka&labels=Type%3A+enhancement
[urls.new_kafka_source_issue]: https://github.com/timberio/vector/issues/new?labels=source%3A+kafka
[urls.vector_chat]: https://chat.vector.dev
