---
description: Accepts `log` events and allows you to sample events with a configurable rate.
---

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     scripts/generate/templates/docs/usage/configuration/transforms/sampler.md.erb
-->

# sampler transform

![][assets.sampler_transform]

{% hint style="warning" %}
The `sampler` transform is in beta. Please see the current
[enhancements][urls.sampler_transform_enhancements] and
[bugs][urls.sampler_transform_bugs] for known issues.
We kindly ask that you [add any missing issues][urls.new_sampler_transform_issue]
as it will help shape the roadmap of this component.
{% endhint %}

The `sampler` transform accepts [`log`][docs.data-model.log] events and allows you to sample events with a configurable rate.

## Config File

{% code-tabs %}
{% code-tabs-item title="vector.toml (simple)" %}
```coffeescript
[transforms.my_transform_id]
  type = "sampler" # must be: "sampler"
  inputs = ["my-source-id"]
  rate = 10

  # For a complete list of options see the "advanced" tab above.
```
{% endcode-tabs-item %}
{% code-tabs-item title="vector.toml (advanced)" %}
```coffeescript
[transforms.sampler_transform]
  # The component type
  # 
  # * required
  # * no default
  # * must be: "sampler"
  type = "sampler"

  # A list of upstream source or transform IDs. See Config Composition for more
  # info.
  # 
  # * required
  # * no default
  inputs = ["my-source-id"]

  # The rate at which events will be forwarded, expressed as 1/N. For example,
  # `rate = 10` means 1 out of every 10 events will be forwarded and the rest
  # will be dropped.
  # 
  # * required
  # * no default
  rate = 10

  # A list of regular expression patterns to exclude events from sampling. If an
  # event's `"message"` key matches _any_ of these patterns it will _not_ be
  # sampled.
  # 
  # * optional
  # * no default
  pass_list = ["[error]", "field2"]
```
{% endcode-tabs-item %}
{% endcode-tabs %}

## How It Works

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.

## Troubleshooting

The best place to start with troubleshooting is to check the
[Vector logs][docs.monitoring#logs]. This is typically located at
`/var/log/vector.log`, then proceed to follow the
[Troubleshooting Guide][docs.troubleshooting].

If the [Troubleshooting Guide][docs.troubleshooting] does not resolve your
issue, please:

1. Check for any [open `sampler_transform` issues][urls.sampler_transform_issues].
2. If encountered a bug, please [file a bug report][urls.new_sampler_transform_bug].
3. If encountered a missing feature, please [file a feature request][urls.new_sampler_transform_enhancement].
4. If you need help, [join our chat/forum community][urls.vector_chat]. You can post a question and search previous questions.


### Alternatives

Finally, consider the following alternatives:

* [`lua` transform][docs.transforms.lua]

## Resources

* [**Issues**][urls.sampler_transform_issues] - [enhancements][urls.sampler_transform_enhancements] - [bugs][urls.sampler_transform_bugs]
* [**Source code**][urls.sampler_transform_source]


[assets.sampler_transform]: ../../../assets/sampler-transform.svg
[docs.configuration#environment-variables]: ../../../usage/configuration#environment-variables
[docs.data-model.log]: ../../../about/data-model/log.md
[docs.monitoring#logs]: ../../../usage/administration/monitoring.md#logs
[docs.transforms.lua]: ../../../usage/configuration/transforms/lua.md
[docs.troubleshooting]: ../../../usage/guides/troubleshooting.md
[urls.new_sampler_transform_bug]: https://github.com/timberio/vector/issues/new?labels=transform%3A+sampler&labels=Type%3A+bug
[urls.new_sampler_transform_enhancement]: https://github.com/timberio/vector/issues/new?labels=transform%3A+sampler&labels=Type%3A+enhancement
[urls.new_sampler_transform_issue]: https://github.com/timberio/vector/issues/new?labels=transform%3A+sampler
[urls.sampler_transform_bugs]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+sampler%22+label%3A%22Type%3A+bug%22
[urls.sampler_transform_enhancements]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+sampler%22+label%3A%22Type%3A+enhancement%22
[urls.sampler_transform_issues]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+sampler%22
[urls.sampler_transform_source]: https://github.com/timberio/vector/tree/master/src/transforms/sampler.rs
[urls.vector_chat]: https://chat.vector.dev
